@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -104,6 +104,12 @@ sub _top
 	print($self->{htmlblocks}->title());
 }
 
+sub _topNoAction
+{
+	my $self = shift;
+	print($self->{htmlblocks}->titleNoAction());
+}
+
 sub _menu
 {
 	my $self = shift;
