@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -27,10 +27,10 @@ use EBox::Config;
 use EBox::ProgressIndicator;
 
 use Error qw(:try);
-
+use JSON;
 
 ## arguments:
-## 	title [required]
+##	title [required]
 sub new {
 	my $class = shift;
 	my $self = $class->SUPER::new('title'    => __('Upgrading'),
@@ -47,28 +47,32 @@ sub _process($) {
 	$self->{params} = [];
 }
 
+sub _menu {
+    print "Step 2";
+    return;
+}
+
 sub _print($) {
-	my $self = shift;
+    my $self = shift;
 
-	my $progressId = $self->param('progress');
-	my $progress = EBox::ProgressIndicator->retrieve($progressId);
+    my $progressId = $self->param('progress');
+    my $progress = EBox::ProgressIndicator->retrieve($progressId);
 
-	my $response;
-	$response .= $progress->stateAsString();
-	$response .= $self->modulesChangedStateAsString();
+    my $response = $progress->stateAsHash();
+    $response->{changed} = $self->modulesChangedStateAsHash();
 
-	print($self->cgi()->header(-charset=>'utf-8'));
-	print $response;
+    print($self->cgi()->header(-charset=>'utf-8'));
+    print to_json($response);
 }
 
 
-sub modulesChangedStateAsString
+sub modulesChangedStateAsHash
 {
     my ($self) = @_;
 
     my $global = EBox::Global->getInstance();
     my $state = $global->unsaved() ? 'changed' : 'notChanged';
-    return "changed:$state";
+    return $state;
 }
 
 1;
