@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -24,28 +24,33 @@ use EBox;
 use EBox::Global;
 use EBox::Gettext;
 
+use Sys::Hostname;
+
 sub new # (error=?, msg=?, cgi=?)
 {
-	my $class = shift;
-	my $self = $class->SUPER::new('title' => __('General Configuration'),
-				      'template' => '/general.mas',
-				      @_);
-	bless($self, $class);
-	return $self;
+    my $class = shift;
+    my $self = $class->SUPER::new('title' => __('General Configuration'),
+                      'template' => '/general.mas',
+                      @_);
+    bless($self, $class);
+    return $self;
 }
 
 sub _process
 {
-	my $self = shift;
+    my $self = shift;
 
-	my $global = EBox::Global->getInstance();
-	my $apache = $global->modInstance('apache');
+    my $global = EBox::Global->getInstance();
+    my $apache = $global->modInstance('apache');
+    my $newHostname = $apache->get_string('hostname');
 
-	my @array = ();
-	push(@array, 'port' => $apache->port());
-	push(@array, 'lang' => EBox::locale());
+    my @array = ();
+    push(@array, 'port' => $apache->port());
+    push(@array, 'lang' => EBox::locale());
+    push(@array, 'hostname' => Sys::Hostname::hostname());
+    push(@array, 'newHostname' => $newHostname);
 
-	$self->{params} = \@array;
+    $self->{params} = \@array;
 }
 
 1;
