@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -40,10 +40,10 @@ sub _process
 
 	if (defined($self->param('halt'))) {
 		root("/sbin/halt");
-		$self->{'msg'} = __("eBox is going down for halt");
+		$self->{'msg'} = __("Zentyal is going down for halt");
 	} elsif (defined($self->param('reboot'))) {
 		root("/sbin/reboot");
-		$self->{'msg'} = __("eBox is going down for reboot");
+		$self->{'msg'} = __("Zentyal is going down for reboot");
 	}
 }
 
