@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@ package EBox::Event::Dispatcher::RSS;
 
 # Class: EBox::Dispatcher::RSS
 #
-# This class is a dispatcher which stores the eBox events in a single
+# This class is a dispatcher which stores the Zentyal events in a single
 # file within the channel
 #
 
@@ -26,7 +26,6 @@ use base 'EBox::Event::Dispatcher::Abstract';
 use strict;
 use warnings;
 
-# eBox uses
 use EBox::Config;
 use EBox::Exceptions::MissingArgument;
 use EBox::Exceptions::External;
@@ -287,21 +286,21 @@ sub _addEventToRSS
 
     if ($create) {
         # Create the channel if it does not exist
-        $rss->channel(title         => __x('eBox alerts channel for {hostname}',
+        $rss->channel(title         => __x('Zentyal alerts channel for {hostname}',
                                          hostname => hostname()),
                       link          => $confModel->linkValue(),
                       description   => __('This channel tracks what happens on '
-                                          . 'this eBox machine along the time'),
+                                          . 'this Zentyal machine along the time'),
                       language      => $self->_currentLanguage(),
 #                      pubDate       => $rssComplaintDate,
                       lastBuildDate => $rssComplaintDate,
                       ttl           => CHANNEL_TTL,
                      );
-        $rss->image(title       => 'eBox platform',
-                    url         => 'http://trac.ebox-platform.com/chrome/common/ebox-logo.png',
-                    link        => 'http://ebox-platform.com',
-                    description => 'eBox platform',
-                    alt         => 'eBox platform',
+        $rss->image(title       => 'Zentyal',
+                    url         => 'http://static.zentyal.org/img/zentyal.png',
+                    link        => 'http://zentyal.org',
+                    description => 'Zentyal',
+                    alt         => 'Zentyal',
                    );
 
     }
@@ -310,13 +309,13 @@ sub _addEventToRSS
                   lastBuildDate => $rssComplaintDate
                  );
 
-    my $descriptionStr = __x('The event has happened in eBox {hostname} '
+    my $descriptionStr = __x('The event has happened in Zentyal {hostname} '
                              . 'from {source}',
                              hostname => hostname(),
                              source   => $event->source());
     $descriptionStr .= '<br><br>' . __x('Go to your {url} to check its status.',
                                     url => '<a href="' . $confModel->linkValue()
-                                    . '">eBox</a>');
+                                    . '">Zentyal</a>');
     $rss->add_item(
                    description => $descriptionStr,
                    title       => ($event->level() . ' : ' . $event->message()),
