@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -136,7 +136,7 @@ sub run
 				       mp => $properties->{mountPoint},
 				      ),
 			level   => 'error',
-                        source  => $self->name(),
+                        source  => 'Free storage space',
 		       );
     }
     elsif ($eventHappened) {
