@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,6 @@ use base 'EBox::Event::Watcher::Base';
 use strict;
 use warnings;
 
-# eBox uses
 use EBox::Event;
 use EBox::Event::Watcher::Base;
 use EBox::Exceptions::Internal;
@@ -233,7 +232,7 @@ sub _description
           $loggersMsg = join(', ', @names);
           # XX Delete
 #           my @loggers = keys %{$loggerTables};
-          
+
 #           $loggersMsg = join( ', ',
 #                               map { $logs->getTableInfo($_)->{name} } @loggers);
       }
@@ -250,13 +249,20 @@ sub _createEvents
 {
     my ($self, $loggerName, $rows) = @_;
 
+    my $helperMod = $self->{logs}->getTableInfo($loggerName)->{helper};
+
     my @retEvents = ();
     foreach my $row (@{$rows}) {
-        my $logger = EBox::Global->modInstance($loggerName);
+        # Remove timestamp field from row to add the source category
+        my $msg = $helperMod->humanEventMessage($row);
+        delete($row->{timestamp});
+        my @keys = sort { $a <=> $b } keys(%{$row});
+        my @values = map { $row->{$_} } @keys;
         push(@retEvents, new EBox::Event(
-                                         message => $logger->humanEventMessage($row),
-                                         level   => 'info',
-                                         source  => $self->name() . '/' . $loggerName,
+                                         message     => $msg,
+                                         level       => 'info',
+                                         source  => "Log observer-$loggerName",
+                                         compMessage => join('_', @values),
                                         )
             );
     }
