@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -24,7 +24,7 @@ package EBox::Event::Watcher::RAID;
 #
 #   Partition events:
 #
-#    - Changing its state: active (sync, resync), faulty, spare, remove
+#    - Changing its state: active (sync, resync), faulty, spare, removed
 #
 #    - Hot additions and removals
 #
@@ -44,7 +44,6 @@ package EBox::Event::Watcher::RAID;
 
 use base 'EBox::Event::Watcher::Base';
 
-# eBox uses
 use EBox::Event;
 use EBox::Gettext;
 use EBox::Global;
@@ -179,7 +178,7 @@ sub Able
 sub _name
   {
 
-      return __('RAID');
+      return 'RAID';
 
   }
 
