@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -28,8 +28,10 @@ package EBox::Event::Watcher::Runit;
 use base 'EBox::Event::Watcher::Base';
 
 use constant WILD_SERVICES => EBox::Config::log() . 'runit/wild-services.log';
+use constant PERIOD => 60;
+use constant MAX_DOWN_PERIODS => 5;
+use constant DOMAIN => 'ebox';
 
-# eBox uses
 use EBox::Event;
 use EBox::Event::Watcher::Base;
 use EBox::Exceptions::Internal;
@@ -65,11 +67,13 @@ sub new
       my ($class) = @_;
 
       my $self = $class->SUPER::new(
-                                    period      => 60,
-                                    domain      => 'ebox',
+                                    period      => PERIOD,
+                                    domain      => DOMAIN,
                                    );
       bless( $self, $class);
 
+      $self->{downPeriods} = {};
+
       return $self;
 
   }
@@ -111,12 +115,13 @@ sub run
       my @modules = $self->_runningAlertServices();
       if (@modules) {
           $msg = __x("The following modules are not running but they are enabled: {modules}\n",
-                  modules => "@modules");
+                     modules => join(', ', @modules) );
 
           return [ new EBox::Event(
-                  message => $msg,
-                  level   => 'error',
-                  source  => $self->name(),
+                  message     => $msg,
+                  level       => 'error',
+                  source      => 'service',
+                  compMessage => join('_', @modules),
                   )];
       }
 
@@ -156,7 +161,7 @@ sub _name
 sub _description
   {
 
-      return __('Check if any eBox service is not running when it is enabled');
+      return __('Check if any Zentyal service is not running when it is enabled');
 
   }
 
@@ -175,9 +180,22 @@ sub _runningAlertServices
         next unless ($mod->can('isRunning'));
         my $enabled = $mod->isEnabled();
         my $running = $mod->isRunning();
+        my $name = $mod->name();
+
         if (not $running and $enabled) {
-            my $name = $mod->printableName();
-            push (@mods, $name);
+            unless (exists $self->{downPeriods}->{$name}) {
+                $self->{downPeriods}->{$name} = 0;
+            }
+
+            if ($self->{downPeriods}->{$name}++ >= MAX_DOWN_PERIODS) {
+                push (@mods, $mod->printableName());
+            }
+
+            EBox::debug("Module $name is not running (" .
+                $self->{downPeriods}->{$name} . ')');
+        } elsif (exists $self->{downPeriods}->{$name}) {
+            EBox::debug("Module $name is running again");
+            delete $self->{downPeriods}->{$name};
         }
     }
 
