@@ -1,5 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -40,7 +39,6 @@ use warnings;
 # Dependencies
 ###################
 
-# eBox uses
 use EBox::Config;
 use EBox::Global;
 use EBox::DBEngineFactory;
@@ -441,15 +439,15 @@ sub _dispatchEventByDispatcher
             my ($exc) = @_;
             EBox::warn($dispatcher->name() . ' is not enabled to send messages');
             EBox::error($exc->stringify());
-            # TODO: Disable dispatcher since it's not enabled to
-            # send events
-            eval { require 'EBox::Global'};
-            my $events = EBox::Global->modInstance('events');
-            # Disable the model
-            $events->enableDispatcher( ref ( $dispatcher ), 0);
-            $events->configureDispatcherModel()->setMessage(
-                    __x('Dispatcher {name} disabled since it is not able to '
-                        . 'send events', name => $dispatcher->name()));
+            # Disable dispatcher since it's not enabled to
+            # send events: This is a non-sense after months of testing
+            # eval { require 'EBox::Global'};
+            # my $events = EBox::Global->modInstance('events');
+            # # Disable the model
+            # $events->enableDispatcher( ref ( $dispatcher ), 0);
+            # $events->configureDispatcherModel()->setMessage(
+            #         __x('Dispatcher {name} disabled since it is not able to '
+            #             . 'send events', name => $dispatcher->name()));
         };
     }
 }
@@ -556,7 +554,7 @@ sub _insertEventInLog
         message  => $event->message(),
        };
 
-    $self->{dbengine}->insert(LOG_TABLE, $values);
+    $self->{dbengine}->unbufferedInsert(LOG_TABLE, $values);
 }
 
 # Method: _logEvent
