@@ -1,5 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -34,7 +33,6 @@ use base qw(EBox::Module::Service
 use strict;
 use warnings;
 
-# eBox uses
 use EBox::Common::Model::EnableForm;
 use EBox::Config;
 use EBox::Event;
@@ -204,6 +202,23 @@ sub actions
     ];
 }
 
+
+# Method: restoreDependencies
+#
+#   Override EBox::Module::Base::restoreDependencies
+#
+sub restoreDependencies
+{
+    my @depends = ();
+
+    if ( EBox::Global->modExists('mail') )  {
+        push(@depends, 'mail');
+    }
+
+    return \@depends;
+}
+
+
 # Method: enableActions
 #
 #       Override EBox::Module::Service::enableActions
@@ -863,43 +878,87 @@ sub _consolidateTable
     return {  $table => $spec };
 }
 
+
+
+sub consolidateReportQueries
+{
+    return [
+            {
+             'target_table' => 'events_report',
+             'query' => {
+                         'select' => 'source, level, sum(nRepeated) AS nEvents',
+                         'from' => 'events',
+                         'group' => 'source,level',
+                        },
+
+            },
+           ];
+}
+
+
+
+
 # Method: report
 #
-#  Returns:
-#    hash ref with a key for each source of event, the values will be
-#     a harsh ref with this fields:
-#
-#         info - number of informative events from the source
-#         warn - number of warning events from the source
-#         error - number of error events from the source
-#         fatal - number of fatal events from the source
-#
-#
 # Overrides:
 #   <EBox::Module::Base::report>
-sub reportDeprecated
+#
+# Returns:
+#
+#   hash ref - the events report
+#
+sub report
 {
-    my ($self) = @_;
+    my ($self, $beg, $end, $options) = @_;
 
-    my %report;
+    my $report = {};
 
-    my $logs = EBox::Global->modInstance('logs');
-    my $yesterday = $logs->yesterdayDate();
+    my $db = EBox::DBEngineFactory::DBEngine();
 
-    my @sourcesLogs = @{ $logs->consolidatedLogForDay(
-                                               'events_accummulated',
-                                                $yesterday
-                                                     )
-                     };
 
-    foreach my $sourceLog (@sourcesLogs) {
-        delete $sourceLog->{date};
-        my $source = delete $sourceLog->{source};
+    my $allAlertsRaw  =  $self->runMonthlyQuery($beg, $end, {
+        'select' => 'level, SUM(nEvents)',
+        'from' => 'events_report',
+        'group' => 'level',
+                                                                  },
+    { 'key' => 'level' }
+   );
 
-        $report{$source} = $sourceLog;
+
+    $report->{'all_alerts'} = {};
+
+    foreach my $key (%{ $allAlertsRaw }) {
+        next if ( ($key eq 'debug') or ($key eq 'info'));
+        my $sum = $allAlertsRaw->{$key}->{sum};
+        defined $sum or
+            next;
+        $report->{'all_alerts'}->{$key} = $sum;
     }
 
-    return \%report;
+
+    my $alertsBySource = {};
+    foreach my $level (qw(warn error fatal)) {
+        my $result =  $self->runMonthlyQuery($beg, $end, {
+                'select' => 'source, sum(nEvents)',
+                'from' => 'events_report',
+                'group' => 'source,level',
+                'where' => qq{level='$level'}
+                                                         },
+                { 'key' => 'source' }
+                                            );
+        foreach my $source (keys %{$result}) {
+            if (not exists $alertsBySource->{$source}) {
+                $alertsBySource->{$source} = {};
+            }
+            my $sum = $result->{$source}->{sum};
+            defined($sum) or next;
+            $alertsBySource->{$source}->{$level} = $sum;
+        }
+    }
+
+    $report->{alerts_by_source} = $alertsBySource;
+
+    return $report;
 }
 
 1;
