@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -31,7 +31,6 @@ use base 'EBox::Model::DataTable';
 use strict;
 use warnings;
 
-# eBox uses
 use EBox;
 use EBox::Config;
 use EBox::Exceptions::Internal;
@@ -154,6 +153,10 @@ sub syncRows
               $modified = 1;
               $removed = 1;
           };
+          unless ( defined($row) ) {
+              $modified = 1;
+              $removed  = 1;
+          }
           next if ($removed);
           my $stored = $row->valueByName('eventDispatcher');
           $storedEventDispatchers{$stored} = 'true';
@@ -171,7 +174,7 @@ sub syncRows
           # XXX Enable Log dispatcher by default and not allow user
           # to disable it
           if ( $enabled ) {
-              $self->{'gconfmodule'}->enableEventElement('dispatcher', 
+              $self->parentModule()->enableEventElement('dispatcher',
                 $dispatcher, 1);
           }
           my %params = (
