@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -33,7 +33,6 @@ package EBox::Events::Model::Dispatcher::Jabber;
 
 use base 'EBox::Model::DataForm';
 
-# eBox uses
 use EBox::Exceptions::InvalidData;
 use EBox::Gettext;
 use EBox::Global;
@@ -224,7 +223,7 @@ sub _table
              printableName  => __('Subscribe'),
              editable       => 1,
              help           => __('Tick this option if ' .
-                 'you want eBox to create an account for ' .
+                 'you want Zentyal to create an account for ' .
                  'the above user')
              ),
 
@@ -234,7 +233,7 @@ sub _table
              size          => 12,
              editable      => 1,
              help          => __('Destination Jabber ID of the messages ' .
-                'generated by eBox,  i.e: you, the eBox admin. Note ' .
+                'generated by Zentyal,  i.e: you, the Zentyal admin. Note ' .
                 'that you need to register this  account manually in ' .
                 'any jabber server')
              ),
