@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -29,7 +29,6 @@ package EBox::Events::Model::Dispatcher::RSS;
 
 use base 'EBox::Model::DataForm';
 
-# eBox uses
 use EBox::Config;
 use EBox::Event::Dispatcher::RSS;
 use EBox::Gettext;
@@ -305,7 +304,7 @@ sub _defaultChannelLink
         }
     }
 
-    return 'http://ebox-platform.com';
+    return 'http://zentyal.org';
 
 
 }
