@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -29,7 +29,6 @@ use base 'EBox::Model::Composite';
 use strict;
 use warnings;
 
-## eBox uses
 use EBox::Gettext;
 
 # Group: Public methods
@@ -44,15 +43,13 @@ use EBox::Gettext;
 #       general events composite
 #
 sub new
-  {
+{
+    my ($class) = @_;
 
-      my ($class) = @_;
+    my $self = $class->SUPER::new();
 
-      my $self = $class->SUPER::new();
-
-      return $self;
-
-  }
+    return $self;
+}
 
 # Group: Protected methods
 
@@ -63,26 +60,24 @@ sub new
 #     <EBox::Model::Composite::_description>
 #
 sub _description
-  {
+{
+    my $description =
+    {
+        components      => [
+                            #'/events/EnableForm',
+                            'ConfigurationComposite',
+        ],
+        layout          => 'top-bottom',
+        name            => 'GeneralComposite',
+        printableName   => __('Events'),
+        pageTitle => __('Events'),
+        headTitle => undef,
+        compositeDomain => 'Events',
+        help            => __('Events module configures Zentyal to help ' .
+                              'informing you about events that happen'),
+    };
 
-      my $description =
-        {
-         components      => [
-#                             '/events/EnableForm',
-                             'ConfigurationComposite',
-                            ],
-         layout          => 'top-bottom',
-         name            => 'GeneralComposite',
-         printableName   => __('Events'),
-         pageTitle => __('Events'),
-         headTitle => undef,
-         compositeDomain => 'Events',
-         help            => __('Events module configures eBox to help ' .
-                               'informing you about events that happen'),
-        };
-
-      return $description;
-
-  }
+    return $description;
+}
 
 1;
