@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,6 @@ use warnings;
 
 use base 'EBox::Module::Base';
 
-use Gnome2::GConf;
 use EBox::Config;
 use EBox::Global;
 use EBox::Exceptions::Internal;
@@ -29,6 +28,7 @@ use EBox::GConfState;
 use EBox::GConfConfig;
 use File::Basename;
 use EBox::Types::File;
+use EBox::Config::Redis;
 
 sub _create # (name)
 {
@@ -42,11 +42,10 @@ sub _create # (name)
         $ebox = "ebox-ro";
     }
     bless($self, $class);
-    $self->{gconf} = Gnome2::GConf::Client->get_default;
-    defined($self->{gconf}) or
-        throw EBox::Exceptions::Internal("Error getting GConf client");
-    $self->gconf->add_dir("/$ebox/modules/". $self->name, 'preload-none');
-    $self->gconf->add_dir("/$ebox/state/". $self->name, 'preload-none');
+    $self->{redis} = EBox::Config::Redis->new();
+    unless (defined($self->{redis})) {
+        throw EBox::Exceptions::Internal("Error getting Redis client");
+    }
     $self->{state} = new EBox::GConfState($self, $self->{ro});
     $self->{config} = new EBox::GConfConfig($self, $self->{ro});
     $self->{helper} = $self->{config};
@@ -70,7 +69,6 @@ sub _helper
 sub _config
 {
     my $self = shift;
-    $self->{gconf}->clear_cache();
     $self->{helper} = $self->{config};
 }
 
@@ -90,8 +88,7 @@ sub initChangedState
         throw EBox::Exceptions::Internal($self->name .
                                           ' module already has changed state');
 
-
-   $self->_dump_to_file();
+    $self->_dump_to_file();
 }
 
 
@@ -107,42 +104,50 @@ sub aroundRestoreConfig
     $self->restoreFilesFromArchive($dir);
   }
 
-
   $self->restoreConfig($dir);
 }
 
-
 # load GConf entries from a file
 sub _load_from_file # (dir?, key?)
 {
-  my ($self, $dir, $key) = @_;
-  ($dir) or $dir = EBox::Config::conf;
+    my ($self, $dir, $key) = @_;
+    ($dir) or $dir = EBox::Config::conf;
 
-  $self->_config();
+    $self->_config();
 
-  my $file =  $self->_bak_file_from_dir($dir);
-  if (not  -f $file)  {
-    EBox::error("GConf backup file missing for module " . $self->name);
-    return;
-  }
+    my $file =  $self->_bak_file_from_dir($dir);
+    if (not  -f $file)  {
+        EBox::error("Backup file missing for module " . $self->name);
+        return;
+    }
 
-  ($key) or $key = $self->_key("");
-  $self->_delete_dir_internal($key);
+    ($key) or $key = $self->_key("");
+
+    open(FILE, "< $file") or EBox::error("Can't open backup file $file: $!");
+    my $line = <FILE>;
+    close(FILE);
+
+    return unless (defined($line));
+
+    if ( $line =~ /^</ ) {
+        # Import from GConf
+        EBox::debug("Old gconf format detected");
+        $self->{redis}->import_dir_from_gconf($file);
+    } else {
+        # YAML file
+        # Import to /temp dir and convert paths to $key dest
+        $self->{redis}->import_dir_from_yaml($file, '/temp');
+        $self->{redis}->backup_dir('/temp/ebox/modules/' . $self->name, $key);
+        $self->{redis}->delete_dir('/temp');
+    }
 
-  system "/usr/bin/gconftool-2 --load=$file $key";
-  if (not ($? == 0)) {
-    throw EBox::Exceptions::Internal("Error while restoring " .
-                                     "configuration from $file");
-  }
 
 }
 
 
-# we override aroundDumpConfig to save gconf data before dump module config
 sub aroundDumpConfig
 {
   my ($self, $dir, @options) = @_;
-
   $self->_dump_to_file($dir);
 
   if ($self->isa('EBox::Model::ModelProvider')) {
@@ -158,12 +163,10 @@ sub _dump_to_file # (dir?)
     my ($self, $dir) = @_;
     $self->_config();
 
-    my $key = "/ebox/modules/" . $self->name;
+    my $key = '/ebox/modules/' . $self->name;
     ($dir) or $dir = EBox::Config::conf;
     my $file = $self->_bak_file_from_dir($dir);
-    `umask 0077; /usr/bin/gconftool-2 --dump $key > $file` and
-        throw EBox::Exceptions::Internal("Error while backing up " .
-                                         "configuration on $file");
+    $self->{redis}->export_dir_to_yaml($key, $file);
 }
 
 
@@ -210,8 +213,6 @@ sub revokeConfig
 }
 
 
-
-
 sub scheduleRestart
 {
     my $self = shift;
@@ -232,21 +233,25 @@ sub _saveConfig
         $self->modelsSaveConfig();
     }
 
-    $self->_load_from_file(undef, "/ebox-ro/modules/". $self->name());
+    $self->_copy_to_ro();
     $self->_saveConfigFiles();
 }
 
+sub _copy_to_ro
+{
+    my ($self) = @_;
+
+    $self->_config();
+    my $key = "/ebox/modules/" . $self->name;
+    $self->{redis}->backup_dir($key, '/ebox-ro/modules/' . $self->name);
+}
+
 sub _backup
 {
     my $self = shift;
     $self->_helper->backup();
 }
 
-#
-# Method: gconf
-#
-#       Returns the current instance of gconf
-#
 # Returns:
 #
 #       Gnome2::GConf object
@@ -254,7 +259,7 @@ sub _backup
 sub gconf
 {
     my $self = shift;
-    return $self->{gconf};
+    EBox::debug("Deprecated");
 }
 
 sub _key # (key)
@@ -262,54 +267,50 @@ sub _key # (key)
     my ($self, $key) = @_;
     return $self->_helper->key($key);
 }
-
 #############
 
-sub _gconf_wrapper # (method, @params?)
+sub _entry_exists # (key)
 {
-    my $self = shift;
-    my $method = shift;
-    my @parms  = @_;
-    my $scalar;
-    my @array;
-
-    my $code = $self->gconf->can($method);
-    unless ($code){
-        throw EBox::Exceptions::Internal("method $method  doesnt exists"
-                                         . " in EBox::GConfModule\n");
-    }
-
-    my $ret = wantarray;
-    eval {
-        if ($ret){
-            @array = &$code($self->gconf, @parms);
-        } else {
-            {
-                # Silent really weird warning which is likeley due to
-                # the perl version
-                no warnings;
-                $scalar = &$code($self->gconf, @parms);
-            }
-        }
-    };
-    if ($@) {
-        throw EBox::Exceptions::Internal("gconf error using function "
-                                         . "$method and params @parms"
-                                         . "\n $@");
-    }
-
-    return wantarray ? @array : $scalar;
+    my ($self, $key) = @_;
+    $key = $self->_key($key);
+    return $self->{redis}->exists($key);
 }
 
+# Method: entry_exists
+#
+#       Given a key referencing an entry tells you if it exists
+#
+# Parameters:
+#
+#       key - entry key
+#
+# Returns:
+#
+#       boolean - True if it exists
+#
+sub entry_exists # (key)
+{
+    my ($self, $key) = @_;
+    $self->_config;
+    return $self->_entry_exists($key);
+}
+
+sub st_entry_exists # (key)
+{
+    my ($self, $key) = @_;
+    $self->_state;
+    return $self->_entry_exists($key);
+}
+
+#############
 
 sub _dir_exists # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    return $self->_gconf_wrapper("dir_exists", $key);
+    return $self->{redis}->dir_exists($key);
 }
 
-#
 # Method: dir_exists
 #
 #       Given a key referencing a directory tells you if it exists
@@ -368,7 +369,7 @@ sub st_all_dirs_base # (key)
 sub _all_entries_base # (key)
 {
     my ($self, $key) = @_;
-    my @array = $self->_all_entries($key);
+    my @array = @{$self->_all_entries($key)};
     my @names = ();
     foreach (@array) {
         push(@names, basename($_));
@@ -405,12 +406,15 @@ sub st_all_entries_base # (key)
 }
 
 #############
-
+sub redis {
+	my ($self) = @_;
+	return $self->{redis};
+}
 sub _all_dirs # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    my @ret = $self->_gconf_wrapper("all_dirs", $key);
+    my @ret = @{$self->redis->all_dirs($key)};
     unless (@ret) {
         @ret = ();
     }
@@ -450,9 +454,8 @@ sub _all_entries # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    my @entries = $self->_gconf_wrapper("all_entries", $key);
-    my @entrypaths = map { $_->{key} } @entries;
-    return @entrypaths;
+    my @entries = @{$self->redis->all_entries($key)};
+    return \@entries;
 }
 
 #
@@ -490,12 +493,8 @@ sub _get_bool # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    $self->gconf->suggest_sync;
-    my $value = $self->_gconf_wrapper("get", $key);
-    unless(defined($value) and ($value->{type} eq 'bool')) {
-        return undef;
-    }
-    if($value->{value}) {
+    my $value = $self->redis->get_bool($key);
+    if($value) {
         return 1;
     } else {
         return 0;
@@ -538,8 +537,7 @@ sub _set_bool # (key, value)
     my ($self, $key, $val) = @_;
     $key = $self->_key($key);
     $self->_backup;
-    $self->_gconf_wrapper("set_bool", $key, $val);
-    $self->gconf->suggest_sync;
+    $self->redis->set_bool($key, $val);
 }
 
 #
@@ -572,12 +570,8 @@ sub _get_int # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    $self->gconf->suggest_sync;
-    my $value = $self->_gconf_wrapper("get", $key);
-    unless(defined($value) and ($value->{type} eq 'int')) {
-        return undef;
-    }
-    return $value->{value};
+    my $value = $self->redis->get_int($key);
+    return $value;
 }
 
 #
@@ -614,8 +608,7 @@ sub _set_int # (key, value)
     my ($self, $key, $val) = @_;
     $key = $self->_key($key);
     $self->_backup;
-    $self->_gconf_wrapper("set_int", $key, $val);
-    $self->gconf->suggest_sync;
+    $self->redis->set_int($key, $val);
 }
 
 #
@@ -648,8 +641,7 @@ sub _get_string # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    $self->gconf->suggest_sync;
-    return $self->_gconf_wrapper("get_string", $key);
+    return $self->redis->get_string($key);
 }
 
 #
@@ -686,8 +678,7 @@ sub _set_string # (key, value)
     my ($self, $key, $val) = @_;
     $key = $self->_key($key);
     $self->_backup;
-    $self->_gconf_wrapper("set_string", $key, $val);
-    $self->gconf->suggest_sync;
+    $self->redis->set_string($key, $val);
 }
 
 #
@@ -720,8 +711,7 @@ sub _get_list # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    $self->gconf->suggest_sync;
-    my $list = $self->_gconf_wrapper("get_list", $key);
+    my $list = $self->redis->get_list($key);
     if ($list) {
         return $list;
     } else {
@@ -832,16 +822,14 @@ sub _get # (key)
 {
     my ($self, $key) = @_;
     $key = $self->_key($key);
-    $self->gconf->suggest_sync;
-    return $self->_gconf_wrapper("get", $key);
+    return $self->redis->get($key);
 }
 
 sub _set #
 {
     my ($self, $key, $value) = @_;
     $key = $self->_key($key);
-    $self->_gconf_wrapper("unset", $key);
-    return $self->_gconf_wrapper("set_string", $key, $value);
+    $self->redis->set_string($key, $value);
 }
 
 #############
@@ -851,8 +839,7 @@ sub _unset # (key)
     my ($self, $key) = @_;
     $key = $self->_key($key);
     $self->_backup;
-    $self->_gconf_wrapper("unset", $key);
-    $self->gconf->suggest_sync;
+    $self->redis->unset($key);
 }
 
 #
@@ -886,8 +873,7 @@ sub _set_list # (key, type, value)
     my ($self, $key, $type, $val) = @_;
     $key = $self->_key($key);
     $self->_backup;
-    $self->_gconf_wrapper("set_list", $key, $type, $val);
-    $self->gconf->suggest_sync;
+    $self->redis->set_list($key, $val);
 }
 
 #
@@ -924,7 +910,7 @@ sub _hash_from_dir # (key)
     my @keys = @{$self->_all_entries_base($dir)};
     foreach (@keys) {
         my $val = $self->_get("$dir/$_");
-        $hash->{$_} = $val->{value};
+        $hash->{$_} = $val;
     }
     return $hash;
 }
@@ -1009,7 +995,6 @@ sub _delete_dir # (key)
     $self->_backup;
     $dir = $self->_key($dir);
     $self->_delete_dir_internal($dir);
-	$self->gconf->suggest_sync;;
 }
 
 #
@@ -1040,16 +1025,7 @@ sub st_delete_dir # (key)
 sub _delete_dir_internal # (key)
 {
     my ($self, $dir) = @_;
-    my @keys = $self->_gconf_wrapper("all_entries", $dir);
-    foreach (@keys) {
-        $self->_gconf_wrapper("unset", $_->{key});
-    }
-    @keys = $self->_gconf_wrapper("all_dirs", $dir);
-    foreach (@keys) {
-        $self->_delete_dir_internal($_);
-    }
-    $self->_gconf_wrapper("unset", $dir);
-    $self->gconf->suggest_sync;
+    $self->redis->delete_dir($dir);
 }
 
 #
@@ -1196,7 +1172,7 @@ sub _fileList
 
     my @files  = map {
         $self->get_string($_);
-    } $self->all_entries($dir);
+    } @{$self->all_entries($dir)};
 
     return \@files;
 }
