@@ -1,5 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -43,21 +42,30 @@ use POSIX qw(setuid setgid setlocale LC_ALL);
 use Perl6::Junction qw(any all);
 
 use Digest::MD5;
+use AptPkg::Cache;
+use File::stat;
 
 # Constants
 use constant {
     PRESAVE_SUBDIR  => EBox::Config::etc() . 'pre-save',
     POSTSAVE_SUBDIR => EBox::Config::etc() . 'post-save',
     TIMESTAMP_KEY   => 'saved_timestamp',
+    DPKG_RUNNING_FILE => '/var/lib/ebox/dpkg_running'
 };
 
+my @CORE_MODULES = qw(sysinfo apache events global logs);
+
+my $lastDpkgStatusMtime = undef;
+my $_cache = undef;
+my $_brokenPackages = {};
 
 #redefine inherited method to create own constructor
 #for Singleton pattern
 sub _new_instance
 {
     my $class = shift;
-    my $self = $class->SUPER::_create(name => 'global', @_);
+    my $self = $class->SUPER::_create(name => 'global', domain => 'ebox',
+                                      printableName => 'global', @_);
     bless($self, $class);
     $self->{'mod_instances'} = {};
     $self->{'mod_instances_hidden'} = {};
@@ -139,7 +147,39 @@ sub _writeModInfo
 sub modExists # (module)
 {
     my ($self, $name) = @_;
-    return defined($self->_className($name));
+
+    # is dpkg command running?
+    my $DPKG_RUNNING = 0;
+    if (-f DPKG_RUNNING_FILE) {
+        $DPKG_RUNNING = 1 ;
+    }
+
+    unless ($DPKG_RUNNING) {
+        if ($ENV{DPKG_RUNNING_VERSION}) {
+            EBox::Sudo::command('touch ' . DPKG_RUNNING_FILE);
+            $DPKG_RUNNING = 1;
+        }
+    }
+
+    # Check if module package is properly installed
+    #
+    # No need to check core modules because if
+    # ebox package is not properly installed nothing
+    # of this is going to work at all.
+    #
+    if ($name eq any(@CORE_MODULES) or $DPKG_RUNNING) {
+        return defined($self->_className($name));
+    } else {
+        # Full package check
+        my $package = "ebox-$name";
+
+        # Special case for the usersandgroups modules that
+        # are the exception for the above naming rule
+        if ($name =~ /^user/) {
+            $package = 'ebox-usersandgroups';
+        }
+        return _packageInstalled($package);
+    }
 }
 
 # Method: modEnabled
@@ -410,12 +450,44 @@ sub prepareSaveAllModules
 {
     my ($self) = @_;
 
-    my $totalTicks = scalar @{$self->modifiedModules('save')}
-      + $self->_nScripts(PRESAVE_SUBDIR, POSTSAVE_SUBDIR);
+    my $totalTicks;
+    my $file = '/var/lib/ebox/.first';
+    if ( -f $file ) {
+        # enable + save modules
+        $totalTicks = scalar @{$self->modNames} * 2;
+    } else {
+        # save changed modules
+        $totalTicks = scalar @{$self->modifiedModules('save')};
+    }
+    $totalTicks += $self->_nScripts(PRESAVE_SUBDIR, POSTSAVE_SUBDIR);
 
     return $self->_prepareActionScript('saveAllModules', $totalTicks);
 }
 
+sub packageCache
+{
+    my $status = stat('/var/lib/dpkg/status');
+    my $currentMtime = $status->mtime();
+
+    if (defined ($lastDpkgStatusMtime)) {
+        # Regenerate cache only if status file has changed
+        if ($currentMtime != $lastDpkgStatusMtime) {
+            $_cache = new AptPkg::Cache;
+            $_brokenPackages = {};
+        }
+    } else {
+        $_cache = new AptPkg::Cache;
+    }
+    $lastDpkgStatusMtime = $currentMtime;
+
+    return $_cache;
+}
+
+sub brokenPackages
+{
+    my @names = keys %{$_brokenPackages};
+    return \@names;
+}
 
 sub _prepareActionScript
 {
@@ -462,6 +534,38 @@ sub saveAllModules
 
         $log->info($msg);
 
+
+        # First instalation modules enable
+        my $file = '/var/lib/ebox/.first';
+        if ( -f $file ) {
+            my $mgr = EBox::ServiceManager->new();
+            @mods = @{$mgr->_dependencyTree()};
+            $modNames = join(' ', @mods);
+
+            foreach my $name (@mods) {
+                $progress->setMessage(__x("Enabling {modName} module",
+                                          modName => $name));
+                $progress->notifyTick();
+
+                next if ($name eq 'dhcp'); # Skip dhcp module
+                next if ($name eq 'users'); # Skip usersandgroups
+
+                my $module = $self->modInstance($name);
+                $module->setInstalled();
+                $module->setConfigured(1);
+                $module->enableService(1);
+                try {
+                    $module->enableActions();
+                } otherwise {
+                    my ($ex) = @_;
+                    my $err = $ex->text();
+                    $module->setConfigured(0);
+                    $module->enableService(0);
+                    EBox::debug("Failed to enable module $name: $err");
+                };
+            }
+        }
+
         my $apache = 0;
         foreach my $name (@mods) {
                 if ($name eq 'apache') {
@@ -475,10 +579,15 @@ sub saveAllModules
 
                 my $mod = $self->modInstance($name);
                 my $class = 'EBox::Module::Service';
-                if ($mod->isa($class) and not $mod->configured()) {
+
+                if ($mod->isa($class)) {
+                    $mod->setInstalled();
+
+                    if (not $mod->configured()) {
                         $mod->_saveConfig();
                         $self->modRestarted($name);
                         next;
+                    }
                 }
 
                 try {
@@ -488,6 +597,11 @@ sub saveAllModules
                 };
         }
 
+        # Delete first time installation file (wizard)
+        if ( -f $file ) {
+            unlink $file;
+        }
+
         # FIXME - tell the CGI to inform the user that apache is restarting
         if ($apache) {
                 $progress->setMessage(__x("Saving {modName} module",
@@ -507,6 +621,7 @@ sub saveAllModules
             # Store a timestamp with the time of the ending
             $self->st_set_int(TIMESTAMP_KEY, time());
             $progress->setAsFinished();
+
             return;
         }
 
@@ -831,7 +946,7 @@ sub modRevDepends # (module)
 # Name: sortModulesByDependencies
 #
 #  Sort a list of modules objects by its dependencies. The dependencies are get
-# using a method that returns the names of the dependencies of each module. 
+# using a method that returns the names of the dependencies of each module.
 #
 #  Parameters:
 #        modules_r          - reference to list of modules
@@ -1055,4 +1170,28 @@ sub _nScripts
     return $nScripts;
 }
 
+sub _packageInstalled
+{
+    my ($name) = @_;
+
+    my $cache = packageCache();
+
+    if (exists $_brokenPackages->{$name}) {
+        return 0;
+    }
+
+    my $installed = 0;
+    if ($cache->exists($name)) {
+        my $pkg = $cache->get($name);
+        if ($pkg->{SelectedState} == AptPkg::State::Install) {
+            $installed = ($pkg->{InstState} == AptPkg::State::Ok and
+                          $pkg->{CurrentState} == AptPkg::State::Installed);
+            unless ($installed) {
+                $_brokenPackages->{$name} = 1;
+            }
+        }
+    }
+    return $installed;
+}
+
 1;
