@@ -1,4 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -67,6 +67,28 @@ sub title
 	return $html;
 }
 
+#
+# Method: titleNoAction
+#
+#	Returns the html code for the title without action buttons
+#
+# Returns:
+#
+#	string - containg the html code for the title
+#
+sub titleNoAction
+{
+	my $global = EBox::Global->getInstance();
+    my $image_title = $global->theme()->{'image_title'};
+
+	my $html = makeHtml('headTitle.mas',
+                             image_title => $image_title,
+                            );
+	return $html;
+}
+
+
+
 #
 # Method: menu
 #
