@@ -1,4 +1,4 @@
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2009-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -45,6 +45,19 @@ sub title
     return EBox::Html::title();
 }
 
+# Method: titleNoAction
+#
+#	Returns the html code for the title without actions
+#
+# Returns:
+#
+#      	string - containg the html code for the title
+#
+sub titleNoAction
+{
+    return EBox::Html::titleNoAction();
+}
+
 # Method: menu
 #
 #	Returns the html code for the menu
