@@ -1,5 +1,4 @@
-# Copyright (C) 2005 Warp Networks S.L., DBS Servicios Informaticos S.L.
-# Copyright (C) 2009 eBox Technologies S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -35,6 +34,7 @@ use EBox::Exceptions::External;
 use EBox::Exceptions::Internal;
 use EBox::DBEngineFactory;
 use EBox::Service;
+use EBox::Logs::SlicedBackup;
 
 use POSIX qw(ceil);
 
@@ -43,7 +43,7 @@ use constant IMAGEPATH => EBox::Config::tmp . '/varimages';
 use constant PIDPATH => EBox::Config::tmp . '/pids/';
 use constant ENABLED_LOG_CONF_DIR => EBox::Config::conf  . '/logs';;
 use constant ENABLED_LOG_CONF_FILE => ENABLED_LOG_CONF_DIR . '/enabled.conf';
-use constant PG_DATA_DIR           => '/var/lib/postgres/data';
+use constant PG_DATA_DIR           => '/var/lib/postgres';
 
 
 #       EBox::Module::Service interface
@@ -100,7 +100,7 @@ sub _loggerdPrecondition
 # Method: enableService
 #
 #   Used to enable a service. Overriddien to notify all LogObserver of the
-#   changes. 
+#   changes.
 #
 # Parameters:
 #
@@ -129,7 +129,7 @@ sub _notifyLogEnable
     foreach my $module (@{ $modules }) {
         $module->enableLog($status);
     }
-    
+
 }
 
 # Method: isRunning
@@ -268,6 +268,18 @@ sub getLogsModules
     return [grep { $_->configured() } @{$global->modInstancesOfType('EBox::LogObserver')}];
 }
 
+# Method: getAllTables
+#
+#       Get the table information from all modules which implements
+#       the log observer
+#
+# Return:
+#
+#       hash ref - the table information indexed by table name (index)
+#       as returned by <EBox::LogObserver::tableInfo> + 'helper'
+#       component which is the module that implements the LogObserver
+#       interface
+#
 sub getAllTables
 {
     my ($self) = @_;
@@ -297,7 +309,9 @@ sub getAllTables
 # Returns:
 #
 #       hash ref - the table information returned by
-#       <EBox::LogObserver::tableInfo>
+#       <EBox::LogObserver::tableInfo> + 'helper'
+#       component which is the module that implements the LogObserver
+#       interface
 #
 sub getTableInfo
 {
@@ -347,27 +361,43 @@ sub getLogDomains
     return \%logdomains;
 }
 
-sub extendedBackup
-{
-  my ($self, %params) = @_;
-  my $dir    = $params{dir};
-
-  my $dbengine = EBox::DBEngineFactory::DBEngine();
-  my $dumpFile = "$dir/eboxlogs.dump";
-
-  $dbengine->dumpDB($dumpFile);
-}
 
 
+# keept for coapmibilty with old extended backups
 sub extendedRestore
 {
   my ($self, %params) = @_;
   my $dir    = $params{dir};
 
   my $dbengine = EBox::DBEngineFactory::DBEngine();
-  my $dumpFile = "$dir/eboxlogs.dump";
+  my $dumpFileBasename = 'eboxlogs';
 
-  $dbengine->restoreDB($dumpFile);
+  $dbengine->restoreDB($dir, $dumpFileBasename);
+}
+
+
+sub backupDomains
+{
+    my $name = 'logs';
+    my %attrs  = (
+                  printableName => __('Logs'),
+                  description   => __(q{Zentyal Server logs database}),
+                 );
+
+    return ($name, \%attrs);
+}
+
+
+sub dumpExtraBackupData
+{
+    my ($self, $dir, %backupDomains) = @_;
+
+    if ($backupDomains{logs} ) {
+        my $dbengine = EBox::DBEngineFactory::DBEngine();
+        my $dumpFileBasename = "eboxlogs";
+
+        $dbengine->backupDB($dir, $dumpFileBasename);
+    }
 }
 
 sub _checkValidDate # (date)
@@ -404,7 +434,7 @@ sub _checkValidDate # (date)
 #       to - String which represents the "to" date in "year-month-day
 #       hour:min:sec" format
 #
-#       index - String the module's name in lower case
+#       index - String the table's name
 #
 #       pagesize - Int the page's size to return the result
 #
@@ -530,10 +560,10 @@ sub totalRecords
 #     table - consolidated table. The suffix '_daily' is added automaticallu
 #     date  - date in format yyyy-mm-dd
 #
-#  Returns: 
+#  Returns:
 #      array reference. Each row will be a hash reference with
 #      column/values as key/values. Remember that it will be always a 'date'
-#      field. 
+#      field.
 #      If there is not data it will return a empty array
 sub consolidatedLogForDay
 {
@@ -542,7 +572,7 @@ sub consolidatedLogForDay
         throw EBox::Exceptions::MissingArgument('date');
     $table or
         throw EBox::Exceptions::MissingArgument('table');
-    
+
     # put the standard 00:00:00  hour
     ($date) = split '\s', $date;
     $date .= ' 00:00:00';
@@ -553,7 +583,7 @@ sub consolidatedLogForDay
     my $dbengine = EBox::DBEngineFactory::DBEngine();
 
     my $sql = "SELECT * FROM $table WHERE date='$date'";
-    
+
     my @results = @{  $dbengine->query($sql) };
     return \@results;
 }
@@ -561,7 +591,7 @@ sub consolidatedLogForDay
 # Method: yesterdayDate
 #
 #  Returns:
-#    the yesterday date in string format so it can used in SQL queries and 
+#    the yesterday date in string format so it can used in SQL queries and
 #    i nthe consolidatedLogForDay method
 sub yesterdayDate
 {
@@ -838,7 +868,8 @@ sub forcePurge
                      __("Lifetime parameter must be a positive number of hours")
                                     );
 
-  my $thresholdDate = $self->_thresholdDate($lifetime);
+  my $now           = time();
+  my $thresholdDate = $self->_thresholdDate($lifetime, $now);
 
   my @tables = map {
       @{  $self->getModTableInfos($_) }
@@ -868,6 +899,7 @@ sub purge
 {
   my ($self) = @_;
 
+  my $now = time();
   my %thresholdByModule = ();
 
   # get the threshold date for each domain
@@ -880,7 +912,7 @@ sub purge
     $lifeTime or
       next;
 
-    my $threshold = $self->_thresholdDate($lifeTime);
+    my $threshold = $self->_thresholdDate($lifeTime, $now);
     $thresholdByModule{$row_r->valueByName('domain')} = $threshold;
   }
 
@@ -906,22 +938,56 @@ sub purge
 # Transform an hour into a localtime
 sub _thresholdDate
 {
-  my ($self, $lifeTime) = @_;
+  my ($self, $lifeTime, $now) = @_;
 
   # lifeTime must be in hours
   my $lifeTimeSeconds = $lifeTime * 3600;
-  my $threshold = time() - $lifeTimeSeconds;
+  my $threshold = $now - $lifeTimeSeconds;
   return scalar localtime($threshold);
 }
 
 # Do perform the purge in a table
-sub _purgeTable #(tablename, timecolumn, thresholdDate)
+sub _purgeTable
 {
   my ($self, $table, $timeCol, $thresholdDate) = @_;
 
-  my $sqlStatement = "DELETE FROM $table WHERE $timeCol < '$thresholdDate'";
+  my $finalThreshold;
   my $dbengine = EBox::DBEngineFactory::DBEngine();
+
+  if (EBox::Logs::SlicedBackup::slicedMode()) {
+      $finalThreshold = EBox::Logs::SlicedBackup::limitPurgeThreshold(
+                                                                      $dbengine,
+                                                                      $table,
+                                                                      $thresholdDate,
+
+                                                                     );
+      if (not defined $finalThreshold) {
+          EBox::info("Cannot purge logs of table $table before $thresholdDate because they are unarchived backup slices");
+          return;
+      } elsif ($thresholdDate ne $finalThreshold) {
+          EBox::info("Log purge of table before $thresholdDate has be restricted to records before $finalThreshold because it were not archived backup slices");
+      }
+
+  } else {
+      $finalThreshold = $thresholdDate;
+  }
+
+  my $sqlStatement = "DELETE FROM $table WHERE $timeCol < '$finalThreshold'";
   $dbengine->query($sqlStatement);
 }
 
+sub archiveBackupSlices
+{
+    my ($self, $force) = @_;
+
+    if (not $force) {
+        my $enabled = EBox::Logs::SlicedBackup::slicedMode();
+        $enabled or
+            return;
+    }
+
+    my $dbengine = EBox::DBEngineFactory::DBEngine();
+    EBox::Logs::SlicedBackup::archive($dbengine);
+}
+
 1;
