@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -534,7 +534,7 @@ sub _addConsolidatedRow
     }
 
 
-        $dbengine->insert($table, $row);
+        $dbengine->unbufferedInsert($table, $row);
     }
 
 }
@@ -610,7 +610,7 @@ sub _updateLastConsolidationDate
     my $updateRes = $dbengine->do($updateSt);
     if ($updateRes == 0) {
         my $row = {  lastDate => $lastDate, consolidatedTable => $table  };
-        $dbengine->insert('consolidation', $row);
+        $dbengine->unbufferedInsert('consolidation', $row);
     }
 }
 
