@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -26,7 +26,6 @@ use base 'EBox::Model::DataTable';
 use strict;
 use warnings;
 
-# eBox uses
 use EBox::Model::Row;
 use EBox::Exceptions::Internal;
 use EBox::Gettext;
@@ -588,26 +587,6 @@ sub formSubmitted
 
 }
 
-# Method: printableActionName
-#
-#      Get the i18ned action name for the form.
-#
-# Returns:
-#
-#      String - the i18ned action name. Default value: 'Change'
-#
-sub printableActionName
-{
-    my ($self) = @_;
-
-    unless (defined ( $self->table()->{'printableActionName'})) {
-        $self->table()->{'printableActionName'} = __('Change');
-    }
-
-    return $self->table()->{'printableActionName'};
-
-}
-
 # Method: AUTOLOAD
 #
 #      This method will intercept any call done to undefined
@@ -953,6 +932,9 @@ sub _row
           my $element = $type->clone();
           $element->setRow($row);
           $element->restoreFromHash();
+          if ( (not defined($element->value())) and $element->defaultValue()) {
+              $element->setValue($element->defaultValue());
+          }
           $row->addElement($element);
       }
       # Dummy id for dataform
