@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -21,6 +21,7 @@ package EBox::Module::Service;
 use base qw(EBox::GConfModule);
 
 use EBox::Config;
+use EBox::Exceptions::Internal;
 use EBox::Global;
 use EBox::Dashboard::ModuleStatus;
 use EBox::Sudo;
@@ -36,7 +37,7 @@ use constant INITDPATH => '/etc/init.d/';
 #
 #   This method is mainly used to show information to the user
 #   about the files which are going to be modified by the service
-#   managed  by eBox
+#   managed by Zentyal
 #
 # Returns:
 #
@@ -83,7 +84,7 @@ sub usedFiles
 #           {
 #             'action' => 'remove samba init script"
 #             'reason' =>
-#                   __('eBox will take care of start and stop the service')
+#                   __('Zentyal will take care of start and stop the service')
 #             'module' => samba
 #           }
 #       ]
@@ -154,6 +155,41 @@ sub enableModDepends
     }
 }
 
+# Method: bootDepends
+#
+#   This method is used to declare which modules need to have its
+#   daemons started before this module ones.
+#
+#   It doesn't state a configuration dependency, it states a boot
+#   dependency.
+#
+#   For example: the samba module needs the printer daemon started before.
+#
+#   By default it returns the modules established in the bootdepends list
+#   in the module YAML file. Override the method if you need something more
+#   specific, e.g., having a dynamic list. If nothing is specified in the
+#   YAML file nor the method is overriden, the enabledepends value is
+#   returned to provide compatibility with the previous behavior.
+#
+# Returns:
+#
+#    array ref containing the dependencies.
+#
+#    Example:
+#
+#       [ 'firewall', 'users' ]
+#
+sub bootDepends
+{
+    my ($self) = @_;
+    my $depends = $self->info()->{'bootdepends'};
+    if(not defined($depends)) {
+        return $self->enableModDepends();
+    } else {
+        return $depends;
+    }
+}
+
 # Method: configured
 #
 #   This method is used to check if the module has been configured.
@@ -223,6 +259,41 @@ sub setConfigured
     return $self->st_set_bool('_serviceConfigured', $status);
 }
 
+# Method: firstInstall
+#
+#   This method is used to check if the module has been recently installed
+#   and has not saved changes yet. This is useful to control which modules
+#   have been configured through wizards.
+#
+# Returns:
+#
+#   boolean
+#
+sub firstInstall
+{
+    my ($self) = @_;
+
+    if ($self->st_get_bool('_serviceInstalled')) {
+        return 0;
+    }
+
+    return 1;
+}
+
+# Method: setInstalled
+#
+#   This method is used to set if the module has been installed
+#
+#   If it's set to true it means that the module has been installed
+#   Call this method is only necessary on first install of the module.
+#
+sub setInstalled
+{
+    my ($self) = @_;
+
+    return $self->st_set_bool('_serviceInstalled', 1);
+}
+
 
 # Method: isEnabled
 #
@@ -273,7 +344,14 @@ sub _isDaemonRunning
         return 1;
     }
     if(daemon_type($daemon) eq 'upstart') {
-        return EBox::Service::running($dname);
+        my $running = 0;
+        try {
+            $running = EBox::Service::running($dname);
+        } catch EBox::Exceptions::Internal with {
+            # If the daemon does not exist, then return false
+            ;
+        };
+        return $running;
     } elsif(daemon_type($daemon) eq 'init.d') {
         my $output;
         my $notOk;
@@ -287,11 +365,13 @@ sub _isDaemonRunning
         if ($notOk) {
             return 0;
         }
-        my $status = @{$output}[0];
+        my $status = join ("\n", @{$output});
         if ($status =~ m{$dname .* running}) {
             return 1;
         } elsif ($status =~ m{$dname .* [ OK ]}) {
             return 1;
+        } elsif ($status =~ m{$dname .*done}s) {
+            return 1;
         } else {
             return 0;
         }
@@ -347,6 +427,7 @@ sub isRunning
 sub addModuleStatus
 {
     my ($self, $section) = @_;
+
     my $enabled = $self->isEnabled();
     my $running = $self->isRunning();
     my $name = $self->name();
@@ -434,8 +515,8 @@ sub showModuleStatus
 #   name of the service and 'type' either 'upstart' or 'init.d', depending
 #   on how the module should be managed.
 #
-#   If the type is 'init.d' an extra 'pidfile' key is needed with the path
-#   to the pidfile the daemon uses. This will be used to check the status.
+#   If the type is 'init.d' an extra 'pidfiles' key is needed with the paths
+#   to the pid files the daemon uses. This will be used to check the status.
 #
 #   It can optionally contain a key 'precondition', which should be a reference
 #   to a class method which will be checked to determine if the given daemon
@@ -611,27 +692,27 @@ sub _regenConfig
 #
 sub restartService
 {
-	my $self = shift;
+    my $self = shift;
 
-	$self->_lock();
-	my $global = EBox::Global->getInstance();
-	my $log = EBox::logger;
+    $self->_lock();
+    my $global = EBox::Global->getInstance();
+    my $log = EBox::logger;
 
-	if (not $self->isEnabled()) {
-		$log->info("Skipping restart for $self->{name} as it's disabled");
-		return;
-	}
+    if (not $self->isEnabled()) {
+        $log->info("Skipping restart for $self->{name} as it's disabled");
+        return;
+    }
 
-	$log->info("Restarting service for module: " . $self->name);
-	try {
-            $self->_regenConfig('restart' => 1);
-	} otherwise  {
-            my ($ex) = @_;
-            $log->error("Error restarting service: $ex");
-            throw $ex;
-        } finally {
-		$self->_unlock();
-	};
+    $log->info("Restarting service for module: " . $self->name);
+    try {
+        $self->_regenConfig('restart' => 1);
+    } otherwise  {
+        my ($ex) = @_;
+        $log->error("Error restarting service: $ex");
+        throw $ex;
+    } finally {
+        $self->_unlock();
+    };
 }
 
 # Method: _supportActions
@@ -758,7 +839,6 @@ sub disableApparmorProfile
             EBox::Sudo::root('invoke-rc.d apparmor restart');
         }
     }
-
 }
 
 1;
