@@ -1,3 +1,18 @@
+# Copyright (C) 2008-2010 eBox Technologies S.L.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2, as
+# published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 package EBox::Report::DiskUsage;
 #
 use strict;
@@ -96,8 +111,6 @@ sub _chart
 
   my $chart = new Chart::Pie( _calcGraphSize($datasets, $chartParams)  );
 
-
-
   $chart->set (
                %{ $chartParams  }
             );
@@ -106,7 +119,6 @@ sub _chart
     $chart->add_dataset(  @{ $ds_r  });
   }
 
-
   $chart->png($imageLocation->{file});
 
 
@@ -240,7 +252,7 @@ sub usage
   }
 
 
-  # calcualte system usage and free space for each file system
+  # calculate system usage and free space for each file system
   foreach my $fileSys (keys %usageByFilesys) {
     exists $fileSystems->{$fileSys} or
       throw EBox::Exceptions::Internal("File system not found: $fileSys");
@@ -271,8 +283,6 @@ sub usage
     $usageByFilesys{$fileSys}->{free}   = $freeSpace;
   }
 
-
-
   return \%usageByFilesys;
 }
 
@@ -330,10 +340,13 @@ sub _chartDatasets
 
   # we put free space and system usage first bz we want they have always the
   # same colors
-  push @labels, __('Free space');
+
+  # we don't translate the strings: 'Free space' and 'System' to avoid
+  # problems with special characters in some lenguages
+  push @labels, 'Free space';
   push @diskUsage, $freeSpace . ' Mb';
 
-  push @labels,     __('System');
+  push @labels,    'System';
   push @diskUsage, $systemUsage . ' Mb';
 
   while (my ($facilityName, $facilityUsage) = each %usageByFacility ) {
