@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -91,7 +91,7 @@ sub enabled
 sub info
 {
   my @mdstat = @{  _mdstatContents() };
-  @mdstat or
+  (@mdstat and (scalar @mdstat > 2)) or
     return undef;
 
   my %info;
@@ -100,6 +100,7 @@ sub info
                                    # the real last section
   my $currentSection;
   my @currentSectionData;
+
   foreach my $line (@mdstat) {
     chomp $line;
     $line =~ s/^\s*//;
