@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -30,7 +30,7 @@ use EBox::Config;
 use EBox::Exceptions::MissingArgument;
 use EBox::Exceptions::Internal;
 use EBox::Global;
-use EBox::Sudo qw(:all);
+use EBox::Sudo;
 
 use Error qw(:try);
 use File::Basename;
@@ -469,13 +469,13 @@ sub checkUserModifications
 
 # Method: modulesInDependOrder
 #
-#     Return a module list ordered by the dependencies
+#     Return a module list ordered by the boot dependencies
 #
 sub modulesInDependOrder
 {
     my ($self) = @_;
     my @modules = map { EBox::Global->modInstance($_) }
-        (@{$self->_dependencyTree()});
+        (@{$self->_dependencyBootTree()});
     return \@modules;
 }
 
@@ -485,6 +485,20 @@ sub _dependencyTree
 {
     my ($self, $tree, $hash) = @_;
 
+    return $self->_genericDependencyTree($tree, $hash, 'enableModDepends');
+}
+
+sub _dependencyBootTree
+{
+    my ($self, $tree, $hash) = @_;
+
+    return $self->_genericDependencyTree($tree, $hash, 'bootDepends');
+}
+
+sub _genericDependencyTree
+{
+    my ($self, $tree, $hash, $func) = @_;
+
     $tree = [] unless (defined($tree));
     $hash = {} unless (defined($hash));
 
@@ -494,7 +508,7 @@ sub _dependencyTree
     for my $mod (@{$global->modInstancesOfType(CLASS)}) {
         next if (exists $hash->{$mod->{'name'}});
         my $depOk = 1;
-        for my $modDep (@{$mod->enableModDepends()}) {
+        for my $modDep (@{$mod->$func()}) {
             unless (exists $hash->{$modDep}) {
                 $depOk = undef;
                 last;
@@ -509,7 +523,7 @@ sub _dependencyTree
     if ($numMods ==  @{$tree}) {
         return $tree;
     } else {
-        return $self->_dependencyTree($tree, $hash);
+        return $self->_genericDependencyTree($tree, $hash, $func);
     }
 }
 
@@ -613,19 +627,12 @@ sub  _getMD5
 {
     my ($self, $path) = @_;
 
-    my $exists = 1;
-    try {
-        root("test -e $path");
-    } otherwise {
+    unless (EBox::Sudo::fileTest('-e', $path)) {
         EBox::info("File $path does not exist. So we won't compute its digest");
-        $exists = undef;
-    };
-
-    unless ($exists) {
-       return "notexists";
+        return 'notexists';
     }
 
-    my $md5 = pop(@{root("md5sum $path | cut -d' ' -f1")});
+    my $md5 = pop(@{EBox::Sudo::root("md5sum $path | cut -d' ' -f1")});
     chomp $md5;
 
     return $md5;
