@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -20,7 +20,6 @@ use warnings;
 
 use base 'EBox::Types::Basic';
 
-# eBox uses
 use EBox;
 use EBox::Gettext;
 use EBox::Exceptions::Internal;
@@ -311,8 +310,7 @@ sub _restoreFromHash
     my $value;
     unless ($value = $self->_fetchFromCache()) {
         my $gconf = $self->row()->GConfModule();
-        my $gconfValue =  $gconf->get($self->_path() . '/' . $self->fieldName());
-	$value = $gconfValue->{value};
+        $value =  $gconf->get($self->_path() . '/' . $self->fieldName());
         $self->_addToCache($value);
     }
     $self->{'value'} = $value;
